summaryrefslogtreecommitdiff
path: root/lisp/printing.el
diff options
context:
space:
mode:
authorPaul Eggert <eggert@cs.ucla.edu>2011-11-24 23:14:48 -0800
committerPaul Eggert <eggert@cs.ucla.edu>2011-11-24 23:14:48 -0800
commite4920bc99dfcee02c3bb83b46a761b0893f76626 (patch)
treea6165f7a6c45f0b4924bad97b21ab179d3e7707e /lisp/printing.el
parentfa4fdb5ca559f8aae4137f8d3b974c14c760360d (diff)
downloademacs-e4920bc99dfcee02c3bb83b46a761b0893f76626.tar.gz
Spelling fixes.
Diffstat (limited to 'lisp/printing.el')
-rw-r--r--lisp/printing.el6
1 files changed, 3 insertions, 3 deletions
diff --git a/lisp/printing.el b/lisp/printing.el
index d6c67cc68a6..2dea24149a7 100644
--- a/lisp/printing.el
+++ b/lisp/printing.el
@@ -547,7 +547,7 @@ Please send all bug fixes and enhancements to
;; `pr-auto-region' Non-nil means region is automagically detected.
;;
;; `pr-auto-mode' Non-nil means major-mode specific printing is
;; prefered over normal printing.
;;
;; `pr-mode-alist' Specify an alist for a major-mode and printing
;; function.
@@ -2426,7 +2426,7 @@ marked instead of all buffer."
(defcustom pr-auto-mode t
- "Non-nil means major-mode specific printing is prefered over normal printing.
+ "Non-nil means major-mode specific printing is preferred over normal printing.
That is, if current major-mode is declared in `pr-mode-alist', the `*-buffer*'
and `*-region*' commands will behave like `*-mode*' commands; otherwise,
@@ -5458,7 +5458,7 @@ If menu binding was not done, calls `pr-menu-bind'."
(defun pr-toggle-mode-menu (&optional no-menu)
- "Toggle whether major-mode specific printing is prefered over normal printing."
+ "Toggle whether major-mode specific printing is preferred over normal printing."
(interactive)
(pr-toggle 'pr-auto-mode "Auto mode"
'printing 1 12 'toggle nil no-menu))
@@ -547,7 +547,7 @@ Please send all bug fixes and enhancements to
;;
;; `pr-auto-mode' Non-nil means major-mode specific printing is
-;; prefered over normal printing.
+;; preferred over normal printing.
;;
;; `pr-mode-alist' Specify an alist for a major-mode and printing